{% load static %}
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->
    <title></title>

    <!-- Bootstrap -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@4.3.1/dist/css/bootstrap.min.css" crossorigin="anonymous" rel="stylesheet">

    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
    <script src="https://oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js" crossorigin="anonymous"></script>
    <script src="https://oss.maxcdn.com/respond/1.4.2/respond.min.js" crossorigin="anonymous"></script>
    <![endif]-->

    <!-- Custom styles for this template -->
    <!-- <link href="css/theme.css" rel="stylesheet"> -->

</head>
<body>

<div class="container">

    <div class="page-header">
        <h1>{{ header }}</h1>

        <form name='f' method='POST' action='checked'>
            <button type="submit" class="btn btn-sm btn-success" name="owner" value="[% owner %]">Checked</button>
        </form>

    </div>

    {% if estates %}
    <div class="list-group">

        {% for estate in estates %}

        <a href="" target="_blank" class="list-group-item{% if estate.new %} active{% endif %}">{{ estate.id }}, {{ estate.price }},- <b>from {{ estate.created }}</b></a>

        {% endfor %}

    </div>
    {% endif %}

</div>

<!-- jQuery (necessary for Bootstrap's JavaScript plugins) -->
<script src="https://ajax.googleapis.com/ajax/libs/jquery/1.11.3/jquery.min.js" crossorigin="anonymous"></script>
<!-- Include all compiled plugins (below), or include individual files as needed -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.3.1/dist/js/bootstrap.min.js" crossorigin="anonymous"></script>
</body>
</html>